@@ -2,7 +2,7 @@
 '''
 mrt2exabgp.py - a script to convert MRT format to ExaBGP format.
 
-Copyright (C) 2020 Tetsumune KISO
+Copyright (C) 2022 Tetsumune KISO
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -387,7 +387,7 @@ def get_bgp_attr(args, params, m, attr):
         line += ' atomic-aggregate'
 
     if attr['type'][0] == BGP_ATTR_T['ORIGIN']:
-        line += ' origin %s' % ORIGIN_T[attr['value']]
+        line += ' origin %s' % ORIGIN_T[attr['value'][0]]
 
     elif attr['type'][0] == BGP_ATTR_T['AS_PATH']: 
         if flags & FLAG_T['SINGLE']:
@@ -490,7 +490,7 @@ def get_bgp_attr(args, params, m, attr):
         line += ' as4-path [%s]' % as4_path
 
     elif attr['type'][0] == BGP_ATTR_T['AS4_AGGREGATOR']:
-        asn = attr['value']['asn']
+        asn = attr['value']['as']
         m = r.search(asn)
         if m is not None:
             asn = int(m.group(1)) * 65536 + int(m.group(2))
