@@ -1,7 +1,7 @@
 '''
 mrtparse - MRT format data parser
 
-Copyright (C) 2020 Tetsumune KISO
+Copyright (C) 2022 Tetsumune KISO
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -34,7 +34,7 @@ try:
 except AttributeError:
     pass
 
-__version__ = '2.0.1'
+__version__ = '2.0.2'
 
 # Magic Number
 GZIP_MAGIC = b'\x1f\x8b'
@@ -740,7 +740,8 @@ class BgpAttr(Base):
         '''
         Decoder for ORIGIN attribute
         '''
-        self.data['value'] = self.val_num(1)
+        self.data['value'] = [self.val_num(1)]
+        self.data['value'].append(ORIGIN_T[self.data['value'][0]])
 
     def unpack_as_path(self):
         '''
